@@ -37,9 +37,10 @@ import click_completion
 # local imports here
 import aprsd
 from aprsd import (
-    client, flask, kissclient, messaging, packets, plugin, stats, threads,
-    trace, utils,
+    flask, messaging, packets, plugin, stats, threads, trace, utils,
 )
+from aprsd import client
+from aprsd import config as aprsd_config
 
 
 # setup the global logger
@@ -48,22 +49,8 @@ LOG = logging.getLogger("APRSD")
 
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
-
 flask_enabled = False
 
-# server_event = threading.Event()
-
-# localization, please edit:
-# HOST = "noam.aprs2.net"     # north america tier2 servers round robin
-# USER = "KM6XXX-9"           # callsign of this aprs client with SSID
-# PASS = "99999"              # google how to generate this
-# BASECALLSIGN = "KM6XXX"     # callsign of radio in the field to send email
-# shortcuts = {
-#   "aa" : "5551239999@vtext.com",
-#   "cl" : "craiglamparter@somedomain.org",
-#   "wb" : "5553909472@vtext.com"
-# }
-
 
 def custom_startswith(string, incomplete):
     """A custom completion match that supports case insensitive matching."""
@@ -159,8 +146,9 @@ def signal_handler(sig, frame):
             ),
         )
         time.sleep(1.5)
-        tracker = messaging.MsgTrack()
-        tracker.save()
+        messaging.MsgTrack().save()
+        packets.WatchList().save()
+        packets.SeenList().save()
         LOG.info(stats.APRSDStats())
         # signal.signal(signal.SIGTERM, sys.exit(0))
         # sys.exit(0)
@@ -172,10 +160,10 @@ def signal_handler(sig, frame):
 # to disable logging to stdout, but still log to file
 # use the --quiet option on the cmdln
 def setup_logging(config, loglevel, quiet):
-    log_level = utils.LOG_LEVELS[loglevel]
+    log_level = aprsd_config.LOG_LEVELS[loglevel]
     LOG.setLevel(log_level)
-    log_format = config["aprsd"].get("logformat", utils.DEFAULT_LOG_FORMAT)
-    date_format = config["aprsd"].get("dateformat", utils.DEFAULT_DATE_FORMAT)
+    log_format = config["aprsd"].get("logformat", aprsd_config.DEFAULT_LOG_FORMAT)
+    date_format = config["aprsd"].get("dateformat", aprsd_config.DEFAULT_DATE_FORMAT)
     log_formatter = logging.Formatter(fmt=log_format, datefmt=date_format)
     log_file = config["aprsd"].get("logfile", None)
     if log_file:
@@ -187,24 +175,17 @@ def setup_logging(config, loglevel, quiet):
     LOG.addHandler(fh)
 
     imap_logger = None
-    if config["aprsd"]["email"].get("enabled", False) and config["aprsd"]["email"][
-        "imap"
-    ].get("debug", False):
+    if config.get("aprsd.email.enabled", default=False) and config.get("aprsd.email.imap.debug", default=False):
 
         imap_logger = logging.getLogger("imapclient.imaplib")
         imap_logger.setLevel(log_level)
         imap_logger.addHandler(fh)
 
-    if (
-        utils.check_config_option(
-            config, ["aprsd", "web", "enabled"],
-            default_fail=False,
-        )
-    ):
+    if config.get("aprsd.web.enabled", default=False):
         qh = logging.handlers.QueueHandler(threads.logging_queue)
         q_log_formatter = logging.Formatter(
-            fmt=utils.QUEUE_LOG_FORMAT,
-            datefmt=utils.QUEUE_DATE_FORMAT,
+            fmt=aprsd_config.QUEUE_LOG_FORMAT,
+            datefmt=aprsd_config.QUEUE_DATE_FORMAT,
         )
         qh.setFormatter(q_log_formatter)
         LOG.addHandler(qh)
@@ -234,11 +215,11 @@ def setup_logging(config, loglevel, quiet):
     "--config",
     "config_file",
     show_default=True,
-    default=utils.DEFAULT_CONFIG_FILE,
+    default=aprsd_config.DEFAULT_CONFIG_FILE,
     help="The aprsd config file to use for options.",
 )
 def check_version(loglevel, config_file):
-    config = utils.parse_config(config_file)
+    config = aprsd_config.parse_config(config_file)
 
     setup_logging(config, loglevel, False)
     level, msg = utils._check_version()
@@ -251,7 +232,7 @@ def check_version(loglevel, config_file):
 @main.command()
 def sample_config():
     """This dumps the config to stdout."""
-    click.echo(utils.dump_default_cfg())
+    click.echo(aprsd_config.dump_default_cfg())
 
 
 @main.command()
@@ -272,7 +253,7 @@ def sample_config():
     "--config",
     "config_file",
     show_default=True,
-    default=utils.DEFAULT_CONFIG_FILE,
+    default=aprsd_config.DEFAULT_CONFIG_FILE,
     help="The aprsd config file to use for options.",
 )
 @click.option(
@@ -312,7 +293,7 @@ def send_message(
     """Send a message to a callsign via APRS_IS."""
     global got_ack, got_response
 
-    config = utils.parse_config(config_file)
+    config = aprsd_config.parse_config(config_file)
     if not aprs_login:
         click.echo("Must set --aprs_login or APRS_LOGIN")
         return
@@ -371,8 +352,8 @@ def send_message(
             sys.exit(0)
 
     try:
-        cl = client.Client(config)
-        cl.setup_connection()
+        client.ClientFactory.setup(config)
+        client.factory.create().client
     except LoginError:
         sys.exit(-1)
 
@@ -399,7 +380,7 @@ def send_message(
         # This will register a packet consumer with aprslib
         # When new packets come in the consumer will process
         # the packet
-        aprs_client = client.get_client()
+        aprs_client = client.factory.create().client
         aprs_client.consumer(rx_packet, raw=False)
     except aprslib.exceptions.ConnectionDrop:
         LOG.error("Connection dropped, reconnecting")
@@ -407,7 +388,7 @@ def send_message(
         # Force the deletion of the client object connected to aprs
         # This will cause a reconnect, next time client.get_client()
         # is called
-        cl.reset()
+        aprs_client.reset()
 
 
 # main() ###
@@ -429,7 +410,7 @@ def send_message(
     "--config",
     "config_file",
     show_default=True,
-    default=utils.DEFAULT_CONFIG_FILE,
+    default=aprsd_config.DEFAULT_CONFIG_FILE,
     help="The aprsd config file to use for options.",
 )
 @click.option(
@@ -450,11 +431,12 @@ def server(
     """Start the aprsd server process."""
     global flask_enabled
     signal.signal(signal.SIGINT, signal_handler)
+    signal.signal(signal.SIGTERM, signal_handler)
 
     if not quiet:
         click.echo("Load config")
 
-    config = utils.parse_config(config_file)
+    config = aprsd_config.parse_config(config_file)
 
     setup_logging(config, loglevel, quiet)
     level, msg = utils._check_version()
@@ -476,54 +458,49 @@ def server(
         trace.setup_tracing(["method", "api"])
     stats.APRSDStats(config)
 
-    if config["aprs"].get("enabled", True):
-        try:
-            cl = client.Client(config)
-            cl.client
-        except LoginError:
-            sys.exit(-1)
+    # Initialize the client factory and create
+    # The correct client object ready for use
+    client.ClientFactory.setup(config)
+    # Make sure we have 1 client transport enabled
+    if not client.factory.is_client_enabled():
+        LOG.error("No Clients are enabled in config.")
+        sys.exit(-1)
 
-        rx_thread = threads.APRSDRXThread(
-            msg_queues=threads.msg_queues,
-            config=config,
-        )
-        rx_thread.start()
-    else:
-        LOG.info(
-            "APRS network connection Not Enabled in config.  This is"
-            " for setups without internet connectivity.",
-        )
+    # Creates the client object
+    LOG.info("Creating client connection")
+    client.factory.create().client
 
     # Create the initial PM singleton and Register plugins
+    LOG.info("Loading Plugin Manager and registering plugins")
     plugin_manager = plugin.PluginManager(config)
     plugin_manager.setup_plugins()
 
     # Now load the msgTrack from disk if any
+    packets.PacketList(config=config)
     if flush:
         LOG.debug("Deleting saved MsgTrack.")
-        messaging.MsgTrack().flush()
+        messaging.MsgTrack(config=config).flush()
+        packets.WatchList(config=config)
+        packets.SeenList(config=config)
     else:
         # Try and load saved MsgTrack list
         LOG.debug("Loading saved MsgTrack object.")
-        messaging.MsgTrack().load()
+        messaging.MsgTrack(config=config).load()
+        packets.WatchList(config=config).load()
+        packets.SeenList(config=config).load()
 
-    packets.PacketList(config=config)
-    packets.WatchList(config=config)
-
-    if kissclient.KISSClient.kiss_enabled(config):
-        kcl = kissclient.KISSClient(config=config)
-        # This initializes the client object.
-        kcl.client
-
-        kissrx_thread = threads.KISSRXThread(msg_queues=threads.msg_queues, config=config)
-        kissrx_thread.start()
+    rx_thread = threads.APRSDRXThread(
+        msg_queues=threads.msg_queues,
+        config=config,
+    )
+    rx_thread.start()
 
     messaging.MsgTrack().restart()
 
     keepalive = threads.KeepAliveThread(config=config)
     keepalive.start()
 
-    web_enabled = utils.check_config_option(config, ["aprsd", "web", "enabled"], default_fail=False)
+    web_enabled = config.get("aprsd.web.enabled", default=False)
 
     if web_enabled:
         flask_enabled = True
