@@ -3,7 +3,7 @@ import logging
 import threading
 import time
 
-from aprsd import utils
+from aprsd import objectstore, utils
 
 
 LOG = logging.getLogger("APRSD")
@@ -29,6 +29,7 @@ class PacketList:
             cls._instance = super().__new__(cls)
             cls._instance.packet_list = utils.RingBuffer(1000)
             cls._instance.lock = threading.Lock()
+            cls._instance.config = kwargs["config"]
         return cls._instance
 
     def __init__(self, config=None):
@@ -50,6 +51,7 @@ class PacketList:
             else:
                 self.total_recv += 1
             self.packet_list.append(packet)
+            SeenList().update_seen(packet)
 
     def get(self):
         with self.lock:
@@ -64,18 +66,20 @@ class PacketList:
             return self.total_tx
 
 
-class WatchList:
+class WatchList(objectstore.ObjectStoreMixin):
     """Global watch list and info for callsigns."""
 
     _instance = None
-    callsigns = {}
+    data = {}
     config = None
 
     def __new__(cls, *args, **kwargs):
         if cls._instance is None:
             cls._instance = super().__new__(cls)
             cls._instance.lock = threading.Lock()
-            cls.callsigns = {}
+            cls._instance.config = kwargs["config"]
+            cls._instance.data = {}
+            cls._instance._init_store()
         return cls._instance
 
     def __init__(self, config=None):
@@ -90,7 +94,7 @@ class WatchList:
                 # a beacon from a callsign or some other mechanism to find
                 # last time a message was seen by aprs-is.  For now this
                 # is all we can do.
-                self.callsigns[call] = {
+                self.data[call] = {
                     "last": datetime.datetime.now(),
                     "packets": utils.RingBuffer(
                         ring_size,
@@ -104,17 +108,18 @@ class WatchList:
             return False
 
     def callsign_in_watchlist(self, callsign):
-        return callsign in self.callsigns
+        return callsign in self.data
 
     def update_seen(self, packet):
-        callsign = packet["from"]
-        if self.callsign_in_watchlist(callsign):
-            self.callsigns[callsign]["last"] = datetime.datetime.now()
-            self.callsigns[callsign]["packets"].append(packet)
+        with self.lock:
+            callsign = packet["from"]
+            if self.callsign_in_watchlist(callsign):
+                self.data[callsign]["last"] = datetime.datetime.now()
+                self.data[callsign]["packets"].append(packet)
 
     def last_seen(self, callsign):
         if self.callsign_in_watchlist(callsign):
-            return self.callsigns[callsign]["last"]
+            return self.data[callsign]["last"]
 
     def age(self, callsign):
         now = datetime.datetime.now()
@@ -149,6 +154,40 @@ class WatchList:
             return False
 
 
+class SeenList(objectstore.ObjectStoreMixin):
+    """Global callsign seen list."""
+
+    _instance = None
+    data = {}
+    config = None
+
+    def __new__(cls, *args, **kwargs):
+        if cls._instance is None:
+            cls._instance = super().__new__(cls)
+            cls._instance.lock = threading.Lock()
+            cls._instance.config = kwargs["config"]
+            cls._instance.data = {}
+            cls._instance._init_store()
+        return cls._instance
+
+    def update_seen(self, packet):
+        callsign = None
+        if "fromcall" in packet:
+            callsign = packet["fromcall"]
+        elif "from" in packet:
+            callsign = packet["from"]
+        else:
+            LOG.warning(f"Can't find FROM in packet {packet}")
+            return
+        if callsign not in self.data:
+            self.data[callsign] = {
+                "last": None,
+                "count": 0,
+            }
+        self.data[callsign]["last"] = str(datetime.datetime.now())
+        self.data[callsign]["count"] += 1
+
+
 def get_packet_type(packet):
     """Decode the packet type from the packet."""
 
