@@ -6,6 +6,7 @@ import inspect
 import logging
 import os
 import re
+import textwrap
 import threading
 
 import pluggy
@@ -17,9 +18,6 @@ from aprsd import client, messaging, packets, threads
 # setup the global logger
 LOG = logging.getLogger("APRSD")
 
-hookspec = pluggy.HookspecMarker("aprsd")
-hookimpl = pluggy.HookimplMarker("aprsd")
-
 CORE_MESSAGE_PLUGINS = [
     "aprsd.plugins.email.EmailPlugin",
     "aprsd.plugins.fortune.FortunePlugin",
@@ -36,8 +34,11 @@ CORE_NOTIFY_PLUGINS = [
     "aprsd.plugins.notify.NotifySeenPlugin",
 ]
 
+hookspec = pluggy.HookspecMarker("aprsd")
+hookimpl = pluggy.HookimplMarker("aprsd")
 
-class APRSDCommandSpec:
+
+class APRSDPluginSpec:
     """A hook specification namespace."""
 
     @hookspec
@@ -62,11 +63,8 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
         self.config = config
         self.message_counter = 0
         self.setup()
-        threads = self.create_threads()
-        if threads:
-            self.threads = threads
-        if self.threads:
-            self.start_threads()
+        self.threads = self.create_threads() or []
+        self.start_threads()
 
     def start_threads(self):
         if self.enabled and self.threads:
@@ -96,10 +94,8 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
     def message_count(self):
         return self.message_counter
 
-    @property
-    def version(self):
-        """Version"""
-        raise NotImplementedError
+    def help(self):
+        return "Help!"
 
     @abc.abstractmethod
     def setup(self):
@@ -122,7 +118,6 @@ class APRSDPluginBase(metaclass=abc.ABCMeta):
             if isinstance(thread, threads.APRSDThread):
                 thread.stop()
 
-    @hookimpl
     @abc.abstractmethod
     def filter(self, packet):
         pass
@@ -158,20 +153,28 @@ class APRSDWatchListPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
             )
             # make sure the timeout is set or this doesn't work
             if watch_list:
-                aprs_client = client.get_client()
+                aprs_client = client.factory.create().client
                 filter_str = "b/{}".format("/".join(watch_list))
                 aprs_client.set_filter(filter_str)
             else:
                 LOG.warning("Watch list enabled, but no callsigns set.")
 
+    @hookimpl
     def filter(self, packet):
+        result = messaging.NULL_MESSAGE
         if self.enabled:
             wl = packets.WatchList()
-            result = messaging.NULL_MESSAGE
             if wl.callsign_in_watchlist(packet["from"]):
                 # packet is from a callsign in the watch list
                 self.rx_inc()
-                result = self.process()
+                try:
+                    result = self.process(packet)
+                except Exception as ex:
+                    LOG.error(
+                        "Plugin {} failed to process packet {}".format(
+                            self.__class__, ex,
+                        ),
+                    )
                 if result:
                     self.tx_inc()
                 wl.update_seen(packet)
@@ -199,6 +202,12 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
         """The regex to match from the caller"""
         raise NotImplementedError
 
+    def help(self):
+        return "{}: {}".format(
+            self.command_name.lower(),
+            self.command_regex,
+        )
+
     def setup(self):
         """Do any plugin setup here."""
         self.enabled = True
@@ -221,7 +230,15 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
             if re.search(self.command_regex, message):
                 self.rx_inc()
                 if self.enabled:
-                    result = self.process(packet)
+                    try:
+                        result = self.process(packet)
+                    except Exception as ex:
+                        LOG.error(
+                            "Plugin {} failed to process packet {}".format(
+                                self.__class__, ex,
+                            ),
+                        )
+                        LOG.exception(ex)
                     if result:
                         self.tx_inc()
                 else:
@@ -230,6 +247,66 @@ class APRSDRegexCommandPluginBase(APRSDPluginBase, metaclass=abc.ABCMeta):
         return result
 
 
+class HelpPlugin(APRSDRegexCommandPluginBase):
+    """Help Plugin that is always enabled.
+
+    This plugin is in this file to prevent a circular import.
+    """
+
+    version = "1.0"
+    command_regex = "^[hH]"
+    command_name = "help"
+
+    def help(self):
+        return "Help: send APRS help or help <plugin>"
+
+    def process(self, packet):
+        LOG.info("HelpPlugin")
+        # fromcall = packet.get("from")
+        message = packet.get("message_text", None)
+        # ack = packet.get("msgNo", "0")
+        a = re.search(r"^.*\s+(.*)", message)
+        command_name = None
+        if a is not None:
+            command_name = a.group(1).lower()
+
+        pm = PluginManager()
+
+        if command_name and "?" not in command_name:
+            # user wants help for a specific plugin
+            reply = None
+            for p in pm.get_plugins():
+                if (
+                    p.enabled and isinstance(p, APRSDRegexCommandPluginBase)
+                    and p.command_name.lower() == command_name
+                ):
+                    reply = p.help()
+
+            if reply:
+                return reply
+
+        list = []
+        for p in pm.get_plugins():
+            LOG.debug(p)
+            if p.enabled and isinstance(p, APRSDRegexCommandPluginBase):
+                name = p.command_name.lower()
+                if name not in list and "help" not in name:
+                    list.append(name)
+
+        list.sort()
+        reply = " ".join(list)
+        lines = textwrap.wrap(reply, 60)
+        replies = ["Send APRS MSG of 'help' or 'help <plugin>'"]
+        for line in lines:
+            replies.append(f"plugins: {line}")
+
+        for entry in replies:
+            LOG.debug(f"{len(entry)} {entry}")
+
+        LOG.debug(f"{replies}")
+        return replies
+
+
 class PluginManager:
     # The singleton instance object for this class
     _instance = None
@@ -255,6 +332,10 @@ class PluginManager:
         if config:
             self.config = config
 
+    def _init(self):
+        self._pluggy_pm = pluggy.PluginManager("aprsd")
+        self._pluggy_pm.add_hookspecs(APRSDPluginSpec)
+
     def load_plugins_from_path(self, module_path):
         if not os.path.exists(module_path):
             LOG.error(f"plugin path '{module_path}' doesn't exist.")
@@ -355,9 +436,12 @@ class PluginManager:
         """Create the plugin manager and register plugins."""
 
         LOG.info("Loading APRSD Plugins")
+        self._init()
+        # Help plugin is always enabled.
+        _help = HelpPlugin(self.config)
+        self._pluggy_pm.register(_help)
+
         enabled_plugins = self.config["aprsd"].get("enabled_plugins", None)
-        self._pluggy_pm = pluggy.PluginManager("aprsd")
-        self._pluggy_pm.add_hookspecs(APRSDCommandSpec)
         if enabled_plugins:
             for p_name in enabled_plugins:
                 self._load_plugin(p_name)
@@ -383,6 +467,13 @@ class PluginManager:
         with self.lock:
             return self._pluggy_pm.hook.filter(packet=packet)
 
+    def stop(self):
+        """Stop all threads created by all plugins."""
+        with self.lock:
+            for p in self.get_plugins():
+                if hasattr(p, "stop_threads"):
+                    p.stop_threads()
+
     def register_msg(self, obj):
         """Register the plugin."""
         self._pluggy_pm.register(obj)
