@@ -4,10 +4,11 @@ import subprocess
 
 from aprsd import plugin, trace
 
+
 LOG = logging.getLogger("APRSD")
 
 
-class FortunePlugin(plugin.APRSDMessagePluginBase):
+class FortunePlugin(plugin.APRSDRegexCommandPluginBase):
     """Fortune."""
 
     version = "1.0"
@@ -15,7 +16,7 @@ class FortunePlugin(plugin.APRSDMessagePluginBase):
     command_name = "fortune"
 
     @trace.trace
-    def command(self, packet):
+    def process(self, packet):
         LOG.info("FortunePlugin")
 
         # fromcall = packet.get("from")
@@ -45,7 +46,7 @@ class FortunePlugin(plugin.APRSDMessagePluginBase):
                 .replace("\t", " ")
             )
         except subprocess.CalledProcessError as ex:
-            reply = "Fortune command failed '{}'".format(ex.output)
+            reply = f"Fortune command failed '{ex.output}'"
         else:
             reply = output
 
