@@ -1,6 +1,6 @@
 import logging
 
-from aprsd import messaging, packets, plugin
+from aprsd import packets, plugin
 
 
 LOG = logging.getLogger("APRSD")
@@ -17,12 +17,8 @@ class NotifySeenPlugin(plugin.APRSDWatchListPluginBase):
 
     version = "1.0"
 
-    def __init__(self, config):
-        """The aprsd config object is stored."""
-        super().__init__(config)
-
     def process(self, packet):
-        LOG.info("BaseNotifyPlugin")
+        LOG.info("NotifySeenPlugin")
 
         notify_callsign = self.config["aprsd"]["watch_list"]["alert_callsign"]
         fromcall = packet.get("from")
@@ -50,4 +46,3 @@ class NotifySeenPlugin(plugin.APRSDWatchListPluginBase):
                     wl.max_delta(),
                 ),
             )
-            return messaging.NULL_MESSAGE
